@@ -26,6 +26,8 @@ class NativeMethods(object):
     ):
         try:
             self._config_object = config_object
+            self._server_url_string=server_url
+            self._api_key_string=api_key
             self._local_lib_path = pathlib.Path(__file__).parent.joinpath("lib")
             self._local_lib_path.mkdir(parents=True, exist_ok=True)
             self._check_and_download_files()
@@ -45,10 +47,10 @@ class NativeMethods(object):
     def _check_and_download_files(self):
         required_files = [
             "lib_fhe.so",
-            "libcrypto-1_1-x64.dll",
-            "libprivid_fhe.dylib",
-            "libssl-1_1-x64.dll",
-            "privid_fhe.dll"
+            # "libcrypto-1_1-x64.dll",
+            # "libprivid_fhe.dylib",
+            # "libssl-1_1-x64.dll",
+            # "privid_fhe.dll"
         ]
        # Create an unauthenticated session
         session = boto3.Session()
@@ -73,6 +75,8 @@ class NativeMethods(object):
 
     def _load_linux_libraries(self):
         self._library_path = str(self._local_lib_path.joinpath("lib_fhe.so").resolve())
+        self._library_path_2 = str(self._local_lib_path.joinpath("libtensorflow-lite.so").resolve())
+        ctypes.CDLL(self._library_path_2, mode=1)
         self._spl_so_face = ctypes.CDLL(self._library_path)
 
     def _load_windows_libraries(self):
@@ -98,68 +102,6 @@ class NativeMethods(object):
         self._local_storage_path = local_storage_path
         self._cache_type = cache_type
 
-
-# class NativeMethods(object):
-#     def __init__(
-#         self,
-#         api_key: str,
-#         server_url: str,
-#         local_storage_path: str,
-#         logging_level: LoggingLevel,
-#         tf_num_thread: int,
-#         cache_type: CacheType,
-#         config_object: ConfigObject = None,
-#     ):
-#         try:
-#             self._config_object = config_object
-#             if platform.system() == "Linux":
-#                 self._library_path = str(
-#                     pathlib.Path(__file__)
-#                     .parent.joinpath("lib/lib_fhe.so")
-#                     .resolve()
-#                 )
-#                 self._spl_so_face = ctypes.CDLL(self._library_path)
-#             elif platform.system() == "Windows":
-#                 self._library_path = str(
-#                     pathlib.Path(__file__)
-#                     .parent.joinpath("lib/privid_fhe.dll")
-#                     .resolve()
-#                 )
-#                 self._library_path_2 = str(
-#                     pathlib.Path(__file__)
-#                     .parent.joinpath("lib/libssl-1_1-x64.dll")
-#                     .resolve()
-#                 )
-#                 self._library_path_3 = str(
-#                     pathlib.Path(__file__)
-#                     .parent.joinpath("lib/libcrypto-1_1-x64.dll")
-#                     .resolve()
-#                 )
-#                 ctypes.CDLL(self._library_path_3, mode=1)
-#                 ctypes.CDLL(self._library_path_2, mode=1)
-#                 self._spl_so_face = ctypes.CDLL(self._library_path)
-#             elif platform.system() == "Darwin":
-#                 self._library_path = str(
-#                     pathlib.Path(__file__)
-#                     .parent.joinpath("lib/libprivid_fhe.dylib")
-#                     .resolve()
-#                 )
-#                 self._spl_so_face = ctypes.CDLL(self._library_path)
-
-#             self._embedding_length = 128
-#             self._num_embeddings = 80
-#             self._aug_size = 224 * 224 * 4 * self._num_embeddings
-#             self._tf_num_thread = tf_num_thread
-#             self._api_key = bytes(api_key, "utf-8")
-#             self._server_url = bytes(server_url, "utf-8")
-#             self._logging_level = logging_level
-#             self._local_storage_path = local_storage_path
-#             self._cache_type = cache_type
-#             self._face_setup()
-#         except Exception as e:
-#             print("Error ", e)
-#             sys.exit(1)
-
     def update_config(self, config_object):
         self._config_object = config_object
         if self._config_object and self._config_object.get_config_param():
@@ -177,37 +119,77 @@ class NativeMethods(object):
 
         ##############################################################################################
         # (ok) PRIVID_API_ATTRIB bool privid_initialize_session(
-        #         const char* api_key, const unsigned int key_api_length,
-        #         const char* base_url, const unsigned int base_url_length,
-        #         const int debug_level,void** session_ptr_out);
+        #         const char* settings_buffer, const unsigned int settings_length,
+        #         void** session_ptr_out);
         ##############################################################################################
 
         self._spl_so_face.privid_initialize_session.argtypes = [
             c_char_p,  # const char* api_key
-            c_int,  # const unsigned int key_api_length
-            c_char_p,  # const char* base_url
-            c_int,  # const unsigned int base_url_length
             c_int,
-            c_int,  # const int debug_level
             POINTER(c_void_p),
         ]  # void** session_ptr_out
         self._spl_so_face.privid_initialize_session.restype = c_bool
         self._spl_so_face.handle = c_void_p()  # TODO rename to session
         # create a session
 
+        def named_urls(path):
+            return { 
+                "named_urls": {
+                    "predict": f"{self._server_url_string}/{path}/predict",
+                    "enroll": f"{self._server_url_string}/{path}/enroll",
+                    "deleteUser": f"{self._server_url_string}/{path}/deleteUser",
+                    "addbillingrecord": f"{self._server_url_string}/addbillingrecord", # Temporary for testing
+                    "api-key/checkApiKeyValid": f"{self._server_url_string}/api_check", # Temporary for testing
+                    "syncUUID": f"{self._server_url_string}/syncUUID" # Temporary for testing
+                 }
+             }
+
+        config_dict = {
+	    "collections": {
+                "default": {
+                    "named_urls": {
+                        "base_url": self._server_url_string
+                   }
+                },
+                "collection_a": named_urls("FACE3_1"),
+                "collection_b": named_urls("FACE3_2"),
+                "collection_c": named_urls("FACE3_3"),
+                "collection_d": named_urls("FACE3_4")
+            },
+            "session_token": self._api_key_string,
+            "debug_level": self._logging_level.value,
+            "request_timeout_ms": 5000
+        }
+
+        config_json = json.dumps(config_dict)
+        c_config_param = c_char_p(bytes(config_json, "utf-8"))
+        c_config_param_len = c_int(len(config_json))
+
         return_type = self._spl_so_face.privid_initialize_session(
-            c_char_p(self._api_key),
-            c_int32(len(self._api_key)),
-            c_char_p(self._server_url),
-            c_int32(len(self._server_url)),
-            c_int32(5000),
-            self._logging_level.value,
-            byref(self._spl_so_face.handle),
-        )
+            c_config_param, c_config_param_len,
+            byref(self._spl_so_face.handle))
+
+        # self._spl_so_face.privid_get_version.argtypes = []
+        # self._spl_so_face.privid_get_version.restype = c_char_p
+
+        # # Call the function and decode the byte string to print
+        # version_bytes = self._spl_so_face.privid_get_version()
+        # version_str = version_bytes.decode('utf-8')  # Decoding to string
+        # print(version_str)
+
         if not return_type:
             raise Exception("Wrong API_KEY or Server URL.")
         ##############################################################################################
 
+        ##############################################################################################
+        # (ok) PRIVID_API_ATTRIB bool privid_set_configuration(void *session_ptr, const char *user_config,
+        # const int user_config_length);
+        ##############################################################################################
+       
+        # c_config_param, c_config_param_len = configure_url("predict", self._spl_so_face)
+        # c_config_param_enroll, c_config_param_enroll_len = configure_url("enroll", self._spl_so_face)
+        # c_config_param_delete, c_config_param_delete_len = configure_url("deleteUser", self._spl_so_face)
+
         ##############################################################################################
         # (ok) PRIVID_API_ATTRIB bool privid_set_configuration(void *session_ptr, const char *user_config,
         # const int user_config_length);
@@ -439,6 +421,19 @@ class NativeMethods(object):
             self._spl_so_face.privid_set_billing_record_threshold(
                 self._spl_so_face.handle, c_config_param, c_config_param_len
             )
+        # privid_doc_scan_face
+        self._spl_so_face.privid_doc_scan_face.argtypes = [
+            c_void_p, c_char_p, c_int, POINTER(c_uint8), c_int, c_int,
+            POINTER(POINTER(c_uint8)), POINTER(c_int), POINTER(POINTER(c_uint8)), POINTER(c_int), 
+            POINTER(c_char_p), POINTER(c_int)]
+        self._spl_so_face.privid_doc_scan_face.restype = c_int
+
+        # privid_doc_scan_barcode
+        self._spl_so_face.privid_doc_scan_barcode.argtypes = [
+            c_void_p, c_char_p, c_int, POINTER(c_uint8), c_int, c_int,
+            POINTER(POINTER(c_uint8)), POINTER(c_int), POINTER(POINTER(c_uint8)), POINTER(c_int), 
+            POINTER(c_char_p), POINTER(c_int)]
+        self._spl_so_face.privid_doc_scan_barcode.restype = c_int
 
     def is_valid_without_age(
         self, image_data: np.array, config_object: ConfigObject = None
@@ -603,12 +598,18 @@ class NativeMethods(object):
             print(e)
             return False
 
-    def delete(self, puid: str) -> Any:
+    def delete(self, puid: str,config_object) -> Any:
         puid = bytes(puid, "utf-8")
         p_buffer_result = c_char_p()
         p_buffer_result_length = c_int()
-        c_config_param = c_char_p(bytes("", "utf-8"))
-        c_config_param_len = c_int(0)
+        if config_object and config_object.get_config_param():
+                c_config_param = c_char_p(
+                    bytes(config_object.get_config_param(), "utf-8")
+                )
+                c_config_param_len = c_int(len(config_object.get_config_param()))
+        else:
+                c_config_param = c_char_p(bytes("", "utf-8"))
+                c_config_param_len = c_int(0)
         self._spl_so_face.privid_user_delete(
             self._spl_so_face.handle,
             c_config_param,
@@ -641,7 +642,7 @@ class NativeMethods(object):
         try:
             left_img_data_buffer = left_image.flatten()
             right_img_data_buffer = right_image.flatten()
-
+            print(len(left_img_data_buffer),len(right_img_data_buffer))
             left_c_img_data_buffer = left_img_data_buffer.ctypes.data_as(
                 POINTER(c_uint8)
             )
@@ -656,17 +657,23 @@ class NativeMethods(object):
             rim_size = (
                 right_image.shape[1] * right_image.shape[0] * right_image.shape[2]
             )
-
             p_buffer_result = c_char_p()
             p_buffer_result_length = c_int()
+            config_object_default = {"face_thresholds_rem_bad_emb_default": 1.15, "face_thresholds_med": 1.15}
+
+            config_default_str = json.dumps(config_object_default)
+
+
             if config_object and config_object.get_config_param():
-                c_config_param = c_char_p(
-                    bytes(config_object.get_config_param(), "utf-8")
-                )
-                c_config_param_len = c_int(len(config_object.get_config_param()))
+                config_param_str = config_object.get_config_param()
             else:
-                c_config_param = c_char_p(bytes("", "utf-8"))
-                c_config_param_len = c_int(0)
+
+                config_param_str = config_default_str
+
+            c_config_param = c_char_p(bytes(config_param_str, "utf-8"))
+            c_config_param_len = c_int(len(config_param_str))
+
+    
             success = self._spl_so_face.privid_face_compare_files(
                 self._spl_so_face.handle,
                 c_float(fudge_factor),
@@ -689,17 +696,10 @@ class NativeMethods(object):
                 )
             len_ = p_buffer_result_length.value
             output_json_str = p_buffer_result.value[:len_].decode()
-
             self._spl_so_face.privid_free_char_buffer(p_buffer_result)
             if output_json_str is not None and len(output_json_str) > 0:
+                
                 output = json.loads(output_json_str)
-                # the status should receive the value of the success of the api call
-                # according to FaceCompareResult (that is used in unit tests!!) comments and thus should have
-                # * 0 : If successfully obtained result from server => API call success
-                # * -1 : In case of error => API call failed
-                # The 'result' in the other hand is a value returned by the operation
-                #  which can be any basic type having any value
-                output["status"] = 0 if success else -1
                 return output
             else:
                 return False
@@ -738,15 +738,20 @@ class NativeMethods(object):
             )
 
             if config_object and config_object.get_config_param():
-                c_config_param = c_char_p(
-                    bytes(config_object.get_config_param(), "utf-8")
-                )
-                c_config_param_len = c_int(len(config_object.get_config_param()))
-            else:
-                config_dict = {}
+                # Load existing config from the object
+                config_dict = json.loads(config_object.get_config_param())
+                # Ensure disable_enroll_mf is always added
                 config_dict["disable_enroll_mf"] = True
-                c_config_param = c_char_p(bytes(json.dumps(config_dict), "utf-8"))
-                c_config_param_len = c_int(len(json.dumps(config_dict)))
+                config_json = json.dumps(config_dict)
+            else:
+                # Create a new config dict with disable_enroll_mf set to True
+                config_dict = {"disable_enroll_mf": True}
+                config_json = json.dumps(config_dict)
+
+            # Common logic for converting the config dict to the required C types
+            c_config_param = c_char_p(bytes(config_json, "utf-8"))
+            c_config_param_len = c_int(len(config_json))
+
 
             best_input_out = c_uint8()  # uint8_t** best_input_out
             best_input_length = c_int()  # int *best_input_length
@@ -785,26 +790,11 @@ class NativeMethods(object):
             p_buffer_images_in = img_data
             c_p_buffer_images_in = p_buffer_images_in.ctypes.data_as(POINTER(c_uint8))
             im_size = im_height * im_width * im_channel
-            p_buffer_embeddings_out = np.zeros(
-                4 * self._embedding_length * self._num_embeddings, dtype=np.float32
-            )
-            c_p_buffer_embeddings_out = p_buffer_embeddings_out.ctypes.data_as(
-                POINTER(c_float)
-            )
-
-            augmented_images = np.zeros(self._aug_size, dtype=np.int8)
-            c_augmented_images = augmented_images.ctypes.data_as(POINTER(c_uint8))
 
+            c_result = c_char_p()
             result_out = np.zeros(1, dtype=np.int32)
             c_result_out = result_out.ctypes.data_as(POINTER(ctypes.c_int32))
 
-            emb_out_lenght = np.zeros(1, dtype=np.int32)
-            emb_out_lenght = emb_out_lenght.ctypes.data_as(POINTER(ctypes.c_int32))
-            c_result = c_char_p()
-            augmented_images_length = np.zeros(1, dtype=np.int32)
-            c_augmented_images_length = augmented_images_length.ctypes.data_as(
-                POINTER(ctypes.c_int32)
-            )
             if config_object and config_object.get_config_param():
                 c_config_param = c_char_p(
                     bytes(config_object.get_config_param(), "utf-8")
@@ -813,6 +803,7 @@ class NativeMethods(object):
             else:
                 c_config_param = c_char_p(bytes("", "utf-8"))
                 c_config_param_len = c_int(0)
+
             self._spl_so_face.privid_face_predict_onefa(
                 self._spl_so_face.handle,
                 c_config_param,
@@ -879,4 +870,65 @@ class NativeMethods(object):
             return output
         except Exception as e:
             print(e)
+            return False
+    
+    def doc_scan_face(self, image_data: np.array, config_object: ConfigObject = None) -> Any:
+        try:
+            img = image_data
+            im_width = img.shape[1]
+            im_height = img.shape[0]
+
+            p_buffer_images_in = img.flatten()
+            c_p_buffer_images_in = p_buffer_images_in.ctypes.data_as(POINTER(c_uint8))
+
+            c_result = c_char_p()
+            c_result_len = c_int()
+            c_cropped_doc = pointer(c_uint8())
+            c_cropped_doc_len = c_int()
+            c_cropped_face = pointer(c_uint8())
+            c_cropped_face_len = c_int()
+            if config_object and config_object.get_config_param():
+                config_dict = json.loads(config_object.get_config_param())
+            else:
+                config_dict = {}
+            default_values = {
+                "threshold_doc_x": 0.0,
+                "threshold_doc_y": 0.0,
+                "threshold_doc_too_far": 0.0,
+                "threshold_doc_too_close": 1.0
+            }
+
+            for key, value in default_values.items():
+                config_dict.setdefault(key, value)
+            config_json = json.dumps(config_dict)
+            c_config_param = c_char_p(bytes(config_json, 'utf-8'))
+            c_config_param_len = c_int(len(config_json))
+
+            self._spl_so_face.privid_doc_scan_face(
+                self._spl_so_face.handle, c_config_param, c_config_param_len,
+                c_p_buffer_images_in, c_int(im_width), c_int(im_height),
+                byref(c_cropped_doc), byref(c_cropped_doc_len),
+                byref(c_cropped_face), byref(c_cropped_face_len),
+                byref(c_result), byref(c_result_len))
+
+            if not c_result.value or not c_result_len.value:
+                raise Exception("Something went wrong. Couldn't process the image for Document.")
+            output_json = json.loads(c_result.value[:c_result_len.value].decode())
+
+
+            if output_json.get("doc_face",{}).get("document_data",{}).get("document_validation_status",-1)==0:
+                doc_info = output_json['doc_face']['document_data']['cropped_document_image']['info']
+                face_info = output_json['doc_face']['cropped_face_image']['info']
+        
+                cropped_doc_bytes = c_cropped_doc[:c_cropped_doc_len.value]
+                output_json["doc_face"]["cropped_document"] =np.uint8(np.reshape(cropped_doc_bytes, (
+                        doc_info['height'], doc_info['width'], doc_info['channels']
+                    )))  
+                cropped_face_bytes = c_cropped_face[:c_cropped_face_len.value]
+                output_json["doc_face"]["cropped_face"] = np.uint8(np.reshape(cropped_face_bytes, (
+                        face_info['height'], face_info['width'], face_info['channels']
+                    )))
+            return output_json
+        except Exception as e:
+            print("Error",e)
             return False
\ No newline at end of file
