@@ -14,6 +14,7 @@ from src.cryptonets_python_sdk.settings.configuration import PARAMETERS
 from src.cryptonets_python_sdk.factor import FaceFactor
 from src.cryptonets_python_sdk.settings.loggingLevel import LoggingLevel
 from src.cryptonets_python_sdk.settings.cacheType import CacheType
+from src.cryptonets_python_sdk.helper.utils import FaceValidationCode
 
 
 def image_path_to_array(image_path: str) -> np.ndarray:
@@ -51,17 +52,31 @@ def test_predict(predict_face_factor, predict_img_path, config=None):
         image_path=predict_img_path, config=config
     )
     print("Duration:", default_timer() - predict_start_time, "\n")
+    
+    if isinstance(predict_handle, list):
+        # Handle the case where predict_handle is a list
+        for index, handle in enumerate(predict_handle):
+            print("Result #{}".format(index + 1))
+            print_details(handle)
+    else:
+        # Handle the case where predict_handle is a single instance
+        print_details(predict_handle)
+
+    return predict_handle
+
+def print_details(handle):
+    """Prints the details of a FaceEnrollPredictResult instance."""
     print(
-        "Status:{}\nMessage:{}\nEnroll Level:{}\nPUID:{}\nGUID:{}\nToken:{}\n".format(
-            predict_handle.status,
-            predict_handle.message,
-            predict_handle.enroll_level,
-            predict_handle.puid,
-            predict_handle.guid,
-            predict_handle.token,
+        "Status:{}\nMessage:{}\nEnroll Level:{}\nPUID:{}\nGUID:{}\nToken:{}\nScore:{}\n".format(
+            handle.status,
+            handle.message,
+            handle.enroll_level,
+            handle.puid,
+            handle.guid,
+            handle.token,
+            handle.score
         )
     )
-    return predict_handle
 
 
 def test_enroll(enroll_face_factor, enroll_img_path, config=None):
@@ -81,11 +96,11 @@ def test_enroll(enroll_face_factor, enroll_img_path, config=None):
     )
 
 
-def test_delete(delete_face_factor, predict_handle):
+def test_delete(delete_face_factor, predict_handle,config):
     print(colored("{}\n{}".format("Delete", "=" * 25), "green"))
     delete_start_time = default_timer()
     print(predict_handle.puid)
-    delete_handle = delete_face_factor.delete(predict_handle.puid)
+    delete_handle = delete_face_factor.delete(predict_handle.puid,config)
     print("Duration:", default_timer() - delete_start_time, "\n")
     print("Status:{}\nMessage:{}".format(delete_handle.status, delete_handle.message))
 
@@ -185,7 +200,7 @@ def setup_test(
     a_cache_type = CacheType.ON if use_cache is False else CacheType.ON
 
     face_factor = FaceFactor(
-        logging_level=LoggingLevel.off,config=config_object
+        logging_level=LoggingLevel.off, config=config_object
     )
 
     return face_factor, image_file_path
@@ -383,22 +398,74 @@ def get_image_paths(folder_path):
                    if os.path.splitext(file)[1].lower() in image_extensions]
     return image_paths
 if __name__ == "__main__":
-    os.environ["PI_SERVER_URL"] = "https://api.prodv2.cryptonets.ai/node"
-    os.environ["PI_API_KEY"] = "00000000000000001962"
-   
-    (face_factor, image_path_1,) = setup_test(
-        "test.jpeg",
-    )
+
+    # (face_factor, image_path,) = setup_test("IMG_3843.jpg")
+    (face_factor, mike_dl,) = setup_test("mike_dl.jpg")
+    (face_factor, mike_face,) = setup_test("mike_face.png")
+    (face_factor, test_im,) = setup_test("18.jpg")
+    (face_factor, test_im_dl,) = setup_test("18_dl.png")
+
+    (face_factor, dl_with_glasses,) = setup_test("dl_with_glasses.png")
     # (face_factor, img1, img2) = setup_compare_test(
     #     "3_predict_cropped_images_0.png", "8.png"
     # )
     # (face_factor, img1, img2) = setup_compare_test("8.png", "8.png")
-    # test_enroll(face_factor, image_path)  # => no billing reservation
-    # result_handle = test_predict(face_factor, image_path) # => no billing reservation
 
-    # test_delete(face_factor, result_handle) # => no billing for delete
+
+    config_param = {
+        PARAMETERS.COLLECTION_NAME:"collection_d",
+        PARAMETERS.ALLOWED_RESULTS: [FaceValidationCode.GlassesOn.value],
+        PARAMETERS.K:100
+
+
+    }
+    config_object = ConfigObject(config_param)
+
+
+    print(colored("{}\n{}".format("Compare", "=" * 25), "green"))
+
+    compare_start_time = default_timer()
+    compare_handle = face_factor.compare_doc_with_face(face_path=mike_face,doc_path=mike_dl)
+    # compare_handle = face_factor.compare_doc_with_face(face_path=test_im,doc_path=test_im_dl)
+    # compare_handle = face_factor.compare_doc_with_face(face_path=test_im,doc_path=dl_with_glasses)
+    print("Duration:", default_timer() - compare_start_time, "\n")
+    print(
+        "Status:{}\nResult:{}\nMessage:{}\nDistance {}\n1VR:{}\n2VR:{}\n".format(
+            compare_handle.status,
+            compare_handle.result,
+            compare_handle.message,
+            compare_handle.distance,
+            compare_handle.first_validation_result,
+            compare_handle.second_validation_result,
+        )
+    )
+
+    # print(colored("{}\n{}".format("Compare", "=" * 25), "green"))
+
+    # compare_start_time = default_timer()
+    # compare_handle = face_factor.compare(image_path_1=mike_face,image_path_2=mike_face)
+    # print("Duration:", default_timer() - compare_start_time, "\n")
+    # print(
+    #     "Status:{}\nResult:{}\nMessage:{}\nMin:{}\nMean:{}\nMax:{}\n1VR:{}\n2VR:{}\n".format(
+    #         compare_handle.status,
+    #         compare_handle.result,
+    #         compare_handle.message,
+    #         compare_handle.distance_min,
+    #         compare_handle.distance_mean,
+    #         compare_handle.distance_max,
+    #         compare_handle.first_validation_result,
+    #         compare_handle.second_validation_result,
+    #     )
+    # )
+
+    test_enroll(face_factor, test_im,config=config_object)  # => no billing reservation
+    
+    result_handle = test_predict(face_factor, test_im, config=config_object) # => no billing reservation
+    # test_delete(face_factor, result_handle, config=config_object)
+    # result_handle = test_predict(face_factor, image_path, config=config_object) #
     # result_handle = test_predict(face_factor, image_path)  # => no billing reservation
-    # test_delete(face_factor, result_handle)
+
+    # test_delete(face_factor)
     # test_predict_enrol_valid_image_with_no_cache()
     # test_valid_with_cache()
     # test_valid(face_factor, "/home/azam/projects/openinfer/python sdk/cryptonets-python-sdk/docs/source/Usage/images/johny.jpg")
@@ -409,15 +476,15 @@ if __name__ == "__main__":
         
 
     # test_age_estimate_with_no_cache()
-    compare_start_time = default_timer()
-    compare_handle = face_factor.compare(image_path_1="/home/azam/projects/openinfer/python sdk/cryptonets-python-sdk/docs/source/Usage/images/tom_hanks.png",image_path_2="/home/azam/projects/openinfer/python sdk/cryptonets-python-sdk/docs/source/Usage/images/tom_hanks_2.jpg")
-    print("Duration:", default_timer() - compare_start_time, "\n")
-    print("Status:{}\nResult:{}\nMessage:{}\nMin:{}\nMean:{}\nMax:{}\n1VR:{}\n2VR:{}\n".format(
-        compare_handle.status,
-        compare_handle.result, compare_handle.message, compare_handle.distance_min,
-        compare_handle.distance_mean,
-        compare_handle.distance_max, compare_handle.first_validation_result,
-        compare_handle.second_validation_result))
+    # compare_start_time = default_timer()
+    # compare_handle = face_factor.compare(image_path_1=img1,image_path_2=img2)
+    # print("Duration:", default_timer() - compare_start_time, "\n")
+    # print("Status:{}\nResult:{}\nMessage:{}\nMin:{}\nMean:{}\nMax:{}\n1VR:{}\n2VR:{}\n".format(
+    #     compare_handle.status,
+    #     compare_handle.result, compare_handle.message, compare_handle.distance_min,
+    #     compare_handle.distance_mean,
+    #     compare_handle.distance_max, compare_handle.first_validation_result,
+    #     compare_handle.second_validation_result))
     # test_compare_with_no_cache()
     # test_get_iso_image_with_cache()
     # test_get_iso_image_with_no_cache()
